@@ -16,7 +16,7 @@ from ramodels.mo._shared import UUIDBase
 
 class Detail(UUIDBase):
     type: Literal[
-        "address", "association", "engagement", "org_unit", "manager", "it"
+        "address", "association", "engagement", "org_unit", "manager", "it", "role"
     ] = Field(
         description="Name of the type of detail we wish to terminate. "
         "Must be a valid lora role_type like:  'address', "
