@@ -17,6 +17,7 @@ from .._shared import OrgUnitRef
 from .._shared import PersonRef
 from .._shared import RoleType
 from .._shared import Validity
+from ._shared import Details
 
 # --------------------------------------------------------------------------------------
 # Role
@@ -52,6 +53,10 @@ class RoleWrite(RoleBase):
     role_type: RoleType = Field(description="Reference to the role type klasse.")
 
 
+class RoleDetail(RoleWrite, Details):
+    pass
+
+
 class Role(MOBase):
     type_: Literal["role"] = Field("role", alias="type", description="The object type.")
     role_type: RoleType = Field(description="Reference to the role type facet")
